@@ -13,6 +13,7 @@ typedef Eo Efl_Ui_List_Empty_Item;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** List Empty Item class. This item have only one swallow space, thus user can
  * decorate item by filling the swallow with any kind of container.
  *
@@ -21,5 +22,6 @@ typedef Eo Efl_Ui_List_Empty_Item;
 #define EFL_UI_LIST_EMPTY_ITEM_CLASS efl_ui_list_empty_item_class_get()
 
 EWAPI const Efl_Class *efl_ui_list_empty_item_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
