@@ -11,13 +11,17 @@ typedef Eo Efl_Ui_Widget;
 #ifndef _EFL_UI_WIDGET_EO_TYPES
 #define _EFL_UI_WIDGET_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Function pointer for on show region hook
  *
  * @ingroup Efl_Ui
  */
 typedef void (*Efl_Ui_Scrollable_On_Show_Region)(void *data, Efl_Canvas_Object *obj, Eina_Rect region);
+#endif /* EFL_BETA_API_SUPPORT */
 
-/** All relevant fields needed for the current state of focus registeration
+/** All relevant fields needed for the current state of focus registration
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Ui
  */
@@ -33,6 +37,8 @@ typedef struct _Efl_Ui_Widget_Focus_State
 
 #endif
 /** Efl UI widget abstract class
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Ui_Widget
  */
@@ -40,6 +46,148 @@ typedef struct _Efl_Ui_Widget_Focus_State
 
 EWAPI const Efl_Class *efl_ui_widget_class_get(void);
 
+#ifdef EFL_BETA_API_SUPPORT
+/**
+ * @brief The cursor to be shown when mouse is over the object
+ *
+ * This is the cursor that will be displayed when mouse is over the object. The
+ * object can have only one cursor set to it so if
+ * @ref efl_ui_widget_cursor_set is called twice for an object, the previous
+ * set will be unset.
+ *
+ * If using X cursors, a definition of all the valid cursor names is listed on
+ * Elementary_Cursors.h. If an invalid name is set the default cursor will be
+ * used.
+ *
+ * Sets or unsets the current cursor.
+ *
+ * If @c cursor is @c null this function will reset the cursor to the default
+ * one.
+ *
+ * @param[in] obj The object.
+ * @param[in] cursor The cursor name, defined either by the display system or
+ * the theme.
+ *
+ * @return @c true if successful.
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Ui_Widget
+ */
+EOAPI Eina_Bool efl_ui_widget_cursor_set(Eo *obj, const char *cursor);
+#endif /* EFL_BETA_API_SUPPORT */
+
+#ifdef EFL_BETA_API_SUPPORT
+/**
+ * @brief The cursor to be shown when mouse is over the object
+ *
+ * This is the cursor that will be displayed when mouse is over the object. The
+ * object can have only one cursor set to it so if
+ * @ref efl_ui_widget_cursor_set is called twice for an object, the previous
+ * set will be unset.
+ *
+ * If using X cursors, a definition of all the valid cursor names is listed on
+ * Elementary_Cursors.h. If an invalid name is set the default cursor will be
+ * used.
+ *
+ * Returns the current cursor name.
+ *
+ * @param[in] obj The object.
+ *
+ * @return The cursor name, defined either by the display system or the theme.
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Ui_Widget
+ */
+EOAPI const char *efl_ui_widget_cursor_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
+
+#ifdef EFL_BETA_API_SUPPORT
+/**
+ * @brief A different style for the cursor.
+ *
+ * This only makes sense if theme cursors are used. The cursor should be set
+ * with @ref efl_ui_widget_cursor_set first before setting its style with this
+ * property.
+ *
+ * Sets a style for the current cursor. Call after
+ * @ref efl_ui_widget_cursor_set.
+ *
+ * @param[in] obj The object.
+ * @param[in] style A specific style to use, eg. default, transparent, ....
+ *
+ * @return @c true if successful.
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Ui_Widget
+ */
+EOAPI Eina_Bool efl_ui_widget_cursor_style_set(Eo *obj, const char *style);
+#endif /* EFL_BETA_API_SUPPORT */
+
+#ifdef EFL_BETA_API_SUPPORT
+/**
+ * @brief A different style for the cursor.
+ *
+ * This only makes sense if theme cursors are used. The cursor should be set
+ * with @ref efl_ui_widget_cursor_set first before setting its style with this
+ * property.
+ *
+ * Returns the current cursor style name.
+ *
+ * @param[in] obj The object.
+ *
+ * @return A specific style to use, eg. default, transparent, ....
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Ui_Widget
+ */
+EOAPI const char *efl_ui_widget_cursor_style_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
+
+#ifdef EFL_BETA_API_SUPPORT
+/**
+ * @brief Whether the cursor may be looked in the theme or not.
+ *
+ * If @c false, the cursor may only come from the render engine, i.e. from the
+ * display manager.
+ *
+ * Enables or disables theme cursors.
+ *
+ * @param[in] obj The object.
+ * @param[in] allow Whether to use theme cursors.
+ *
+ * @return @c true if successful.
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Ui_Widget
+ */
+EOAPI Eina_Bool efl_ui_widget_cursor_theme_search_enabled_set(Eo *obj, Eina_Bool allow);
+#endif /* EFL_BETA_API_SUPPORT */
+
+#ifdef EFL_BETA_API_SUPPORT
+/**
+ * @brief Whether the cursor may be looked in the theme or not.
+ *
+ * If @c false, the cursor may only come from the render engine, i.e. from the
+ * display manager.
+ *
+ * Returns the current state of theme cursors search.
+ *
+ * @param[in] obj The object.
+ *
+ * @return Whether to use theme cursors.
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Ui_Widget
+ */
+EOAPI Eina_Bool efl_ui_widget_cursor_theme_search_enabled_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
+
 #ifdef EFL_UI_WIDGET_PROTECTED
 /**
  * @brief This is the internal canvas object managed by a widget.
@@ -53,6 +201,8 @@ EWAPI const Efl_Class *efl_ui_widget_class_get(void);
  * @param[in] obj The object.
  * @param[in] sobj A canvas object (often a @ref Efl_Canvas_Layout object).
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI void efl_ui_widget_resize_object_set(Eo *obj, Efl_Canvas_Object *sobj);
@@ -61,6 +211,10 @@ EOAPI void efl_ui_widget_resize_object_set(Eo *obj, Efl_Canvas_Object *sobj);
 /**
  * @brief Whether the widget is enabled (accepts and reacts to user inputs).
  *
+ * The property works counted, this means, whenever n-caller set the value to
+ * @c true, n-caller have to set it to @c false in order to get it out of the
+ * disabled state again.
+ *
  * Each widget may handle the disabled state differently, but overall disabled
  * widgets shall not respond to any input events. This is @c false by default,
  * meaning the widget is enabled.
@@ -73,6 +227,8 @@ EOAPI void efl_ui_widget_resize_object_set(Eo *obj, Efl_Canvas_Object *sobj);
  * @param[in] obj The object.
  * @param[in] disabled @c true if the widget is disabled.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI void efl_ui_widget_disabled_set(Eo *obj, Eina_Bool disabled);
@@ -80,6 +236,10 @@ EOAPI void efl_ui_widget_disabled_set(Eo *obj, Eina_Bool disabled);
 /**
  * @brief Whether the widget is enabled (accepts and reacts to user inputs).
  *
+ * The property works counted, this means, whenever n-caller set the value to
+ * @c true, n-caller have to set it to @c false in order to get it out of the
+ * disabled state again.
+ *
  * Each widget may handle the disabled state differently, but overall disabled
  * widgets shall not respond to any input events. This is @c false by default,
  * meaning the widget is enabled.
@@ -94,6 +254,8 @@ EOAPI void efl_ui_widget_disabled_set(Eo *obj, Eina_Bool disabled);
  *
  * @return @c true if the widget is disabled.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI Eina_Bool efl_ui_widget_disabled_get(const Eo *obj);
@@ -115,12 +277,14 @@ EOAPI Eina_Bool efl_ui_widget_disabled_get(const Eo *obj);
  * @param[in] style Name of the style to use. Refer to each widget's
  * documentation for the available style names, or to the themes in use.
  *
- * @return Whether the style was successfully applied or not, see the values of
- * @ref Efl_Ui_Theme_Apply for more information.
+ * @return Whether the style was successfully applied or not, see the
+ * Efl.Ui.Theme.Apply_Error subset of @ref Eina_Error for more information.
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Ui_Widget
  */
-EOAPI Efl_Ui_Theme_Apply efl_ui_widget_style_set(Eo *obj, const char *style);
+EOAPI Eina_Error efl_ui_widget_style_set(Eo *obj, const char *style);
 #endif
 
 /**
@@ -140,6 +304,8 @@ EOAPI Efl_Ui_Theme_Apply efl_ui_widget_style_set(Eo *obj, const char *style);
  * @return Name of the style to use. Refer to each widget's documentation for
  * the available style names, or to the themes in use.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI const char *efl_ui_widget_style_get(const Eo *obj);
@@ -163,9 +329,11 @@ EOAPI const char *efl_ui_widget_style_get(const Eo *obj);
  *
  * @return @c true on success, @c false otherwise
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
-EOAPI Eina_Bool efl_ui_widget_event(Eo *obj, const Efl_Event *eo_event, Efl_Canvas_Object *source);
+EOAPI Eina_Bool efl_ui_widget_input_event_handler(Eo *obj, const Efl_Event *eo_event, Efl_Canvas_Object *source);
 #endif
 
 /**
@@ -185,6 +353,8 @@ EOAPI Eina_Bool efl_ui_widget_event(Eo *obj, const Efl_Event *eo_event, Efl_Canv
  * @param[in] obj The object.
  * @param[in] can_focus Whether the object is focusable.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI void efl_ui_widget_focus_allow_set(Eo *obj, Eina_Bool can_focus);
@@ -207,6 +377,8 @@ EOAPI void efl_ui_widget_focus_allow_set(Eo *obj, Eina_Bool can_focus);
  *
  * @return Whether the object is focusable.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI Eina_Bool efl_ui_widget_focus_allow_get(const Eo *obj);
@@ -219,11 +391,11 @@ EOAPI Eina_Bool efl_ui_widget_focus_allow_get(const Eo *obj);
  * from their @ref Efl_Object or @ref Efl_Canvas_Object hierarchy. This is
  * meant for internal handling.
  *
- * See also @ref efl_ui_widget_top_get.
- *
  * @param[in] obj The object.
  * @param[in] parent Widget parent object
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI void efl_ui_widget_parent_set(Eo *obj, Efl_Ui_Widget *parent);
@@ -237,42 +409,18 @@ EOAPI void efl_ui_widget_parent_set(Eo *obj, Efl_Ui_Widget *parent);
  * from their @ref Efl_Object or @ref Efl_Canvas_Object hierarchy. This is
  * meant for internal handling.
  *
- * See also @ref efl_ui_widget_top_get.
- *
  * @param[in] obj The object.
  *
  * @return Widget parent object
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI Efl_Ui_Widget *efl_ui_widget_parent_get(const Eo *obj);
 #endif
 
-/**
- * @brief Root widget in the widget hierarchy.
- *
- * This returns the top widget, in terms of widget hierarchy. This is usually a
- * window (@Efl.Ui.Win). This function walks the list of
- * @ref efl_ui_widget_parent_get.
- *
- * If this widget has no parent (in terms of widget hierarchy) this will return
- * @c null.
- *
- * @note This may not be a display manager window in case of nested canvases.
- * If a "real" window is required, then you might want to verify that the
- * returned object is a @c Efl.Ui.Win_Inlined, and then get
- * @c Efl.Ui.Win_Inlined.inlined_parent to find an object in the master window.
- *
- * See also @ref efl_ui_widget_parent_get.
- *
- * @param[in] obj The object.
- *
- * @return Top widget, usually a window.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI Efl_Ui_Widget *efl_ui_widget_top_get(const Eo *obj);
-
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Accessibility information.
  *
@@ -285,10 +433,14 @@ EOAPI Efl_Ui_Widget *efl_ui_widget_top_get(const Eo *obj);
  * @param[in] obj The object.
  * @param[in] txt Accessibility text description.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI void efl_ui_widget_access_info_set(Eo *obj, const char *txt);
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Accessibility information.
  *
@@ -302,11 +454,14 @@ EOAPI void efl_ui_widget_access_info_set(Eo *obj, const char *txt);
  *
  * @return Accessibility text description.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI const char *efl_ui_widget_access_info_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_UI_WIDGET_BETA
+#ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_UI_WIDGET_PROTECTED
 /**
  * @brief Hook function called when widget is activated through accessibility.
@@ -319,13 +474,15 @@ EOAPI const char *efl_ui_widget_access_info_get(const Eo *obj);
  *
  * @return @c true on success, @c false otherwise
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI Eina_Bool efl_ui_widget_on_access_activate(Eo *obj, Efl_Ui_Activate act);
 #endif
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_UI_WIDGET_BETA
+#ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_UI_WIDGET_PROTECTED
 /**
  * @brief Hook function called when accessibility is changed on the widget.
@@ -336,15 +493,24 @@ EOAPI Eina_Bool efl_ui_widget_on_access_activate(Eo *obj, Efl_Ui_Activate act);
  * @param[in] obj The object.
  * @param[in] enable @c true if accessibility is enabled.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI void efl_ui_widget_on_access_update(Eo *obj, Eina_Bool enable);
 #endif
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_UI_WIDGET_PROTECTED
 /**
- * @brief Virtual function handling sub objects being added.
+ * @brief Virtual function customizing sub objects being added.
+ *
+ * When a widget is added as a sub-object of another widget (like list elements
+ * inside a list container, for example) some of its properties are
+ * automatically adapted to the parent's current values (like focus, access,
+ * theme, scale, mirror, scrollable child get, translate, display mode set,
+ * tree dump). Override this method if you want to customize differently
+ * sub-objects being added to this object.
  *
  * Sub objects can be any canvas object, not necessarily widgets.
  *
@@ -355,6 +521,8 @@ EOAPI void efl_ui_widget_on_access_update(Eo *obj, Eina_Bool enable);
  *
  * @return Indicates if the operation succeeded.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI Eina_Bool efl_ui_widget_sub_object_add(Eo *obj, Efl_Canvas_Object *sub_obj);
@@ -362,11 +530,18 @@ EOAPI Eina_Bool efl_ui_widget_sub_object_add(Eo *obj, Efl_Canvas_Object *sub_obj
 
 #ifdef EFL_UI_WIDGET_PROTECTED
 /**
- * @brief Virtual function handling sub objects being removed.
+ * @brief Virtual function customizing sub objects being removed.
+ *
+ * When a widget is removed as a sub-object from another widget
+ * (@Efl.Pack.unpack, @ref efl_content_unset, for example) some of its
+ * properties are automatically adjusted.(like focus, access, tree dump)
+ * Override this method if you want to customize differently sub-objects being
+ * removed to this object.
  *
  * Sub objects can be any canvas object, not necessarily widgets.
  *
- * See also @ref efl_ui_widget_parent_get.
+ * See also @ref efl_ui_widget_parent_get and
+ * @ref efl_ui_widget_sub_object_add.
  *
  * @param[in] obj The object.
  * @param[in] sub_obj Sub object to be removed. Should be a child of this
@@ -374,98 +549,13 @@ EOAPI Eina_Bool efl_ui_widget_sub_object_add(Eo *obj, Efl_Canvas_Object *sub_obj
  *
  * @return Indicates if the operation succeeded.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI Eina_Bool efl_ui_widget_sub_object_del(Eo *obj, Efl_Canvas_Object *sub_obj);
 #endif
 
-/**
- * @brief Whether the widget's automatic orientation is enabled or not.
- *
- * Orientation mode is used for widgets to change their style or send signals
- * based on the canvas rotation (i.e. the window orientation). If the
- * orientation mode is enabled, the widget will emit signals such as
- * "elm,state,orient,N" where @c N is one of 0, 90, 180, 270, depending on the
- * window orientation. Such signals may be handled by the theme in order to
- * provide a different look for the widget based on the canvas orientation.
- *
- * By default orientation mode is enabled.
- *
- * See also @ref efl_ui_widget_on_orientation_update.
- *
- * @param[in] obj The object.
- * @param[in] mode How window orientation should affect this widget.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI void efl_ui_widget_orientation_mode_set(Eo *obj, Efl_Ui_Widget_Orientation_Mode mode);
-
-/**
- * @brief Whether the widget's automatic orientation is enabled or not.
- *
- * Orientation mode is used for widgets to change their style or send signals
- * based on the canvas rotation (i.e. the window orientation). If the
- * orientation mode is enabled, the widget will emit signals such as
- * "elm,state,orient,N" where @c N is one of 0, 90, 180, 270, depending on the
- * window orientation. Such signals may be handled by the theme in order to
- * provide a different look for the widget based on the canvas orientation.
- *
- * By default orientation mode is enabled.
- *
- * See also @ref efl_ui_widget_on_orientation_update.
- *
- * @param[in] obj The object.
- *
- * @return How window orientation should affect this widget.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI Efl_Ui_Widget_Orientation_Mode efl_ui_widget_orientation_mode_get(const Eo *obj);
-
-#ifdef EFL_UI_WIDGET_PROTECTED
-/**
- * @brief Virtual function handling canvas orientation changes.
- *
- * This method will be called recursively from the top widget (the window) to
- * all the children objects whenever the window rotation is changed. The given
- * @c rotation will be one of 0, 90, 180, 270 or the special value -1 if
- * @ref efl_ui_widget_orientation_mode_get is @c disabled.
- *
- * If @ref efl_ui_widget_orientation_mode_get is @c default, the widget
- * implementation will emit the signal "elm,state,orient,$R" will be emitted
- * (where @c R is the rotation angle in degrees).
- *
- * @note This function may be called even if the orientation has not actually
- * changed, like when a widget needs to be reconfigured.
- *
- * See also @ref efl_ui_widget_orientation_mode_get.
- *
- * @param[in] obj The object.
- * @param[in] rotation Orientation in degrees: 0, 90, 180, 270 or -1 if
- * @ref efl_ui_widget_orientation_mode_get is @c disabled.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI void efl_ui_widget_on_orientation_update(Eo *obj, int rotation);
-#endif
-
-#ifdef EFL_UI_WIDGET_PROTECTED
-/**
- * @brief Virtual function called when the widget becomes disabled.
- *
- * This may be triggered even if this widget is not disabled, as the parent
- * widget could be disabled and propagate its state.
- *
- * @param[in] obj The object.
- * @param[in] disabled The new value of @ref efl_ui_widget_disabled_get.
- *
- * @return Indicates if the operation succeeded.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI Eina_Bool efl_ui_widget_on_disabled_update(Eo *obj, Eina_Bool disabled);
-#endif
-
 #ifdef EFL_UI_WIDGET_PROTECTED
 /**
  * @brief Virtual function called when the widget needs to re-apply its theme.
@@ -482,88 +572,52 @@ EOAPI Eina_Bool efl_ui_widget_on_disabled_update(Eo *obj, Eina_Bool disabled);
  * @return Indicates success, and if the current theme or default theme was
  * used.
  *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI Efl_Ui_Theme_Apply efl_ui_widget_theme_apply(Eo *obj);
-#endif
-
-#ifdef EFL_UI_WIDGET_PROTECTED
-/**
- * @brief Hook function called when the @ref efl_ui_widget_show_region_get is
- * changed.
- *
- * See also @ref efl_ui_widget_show_region_get.
- *
- * @param[in] obj The object.
- * @param[in] func Region hook function
+ * @since 1.22
  *
  * @ingroup Efl_Ui_Widget
  */
-EOAPI void efl_ui_widget_on_show_region_hook_set(Eo *obj, void *func_data, Efl_Ui_Scrollable_On_Show_Region func, Eina_Free_Cb func_free_cb);
-#endif
-
-#ifdef EFL_UI_WIDGET_PROTECTED
-/**
- * @brief Region inside the widget to show.
- *
- * See also @ref efl_ui_widget_on_show_region_hook_set.
- *
- * Request parent scrollers to pan around so that this region of the widget
- * becomes visible.
- *
- * If @c force is @c true this will trigger scroller changes and the
- * @ref efl_ui_widget_on_show_region_hook_set to be called even if the region
- * is unchanged.
- *
- * @param[in] obj The object.
- * @param[in] region The region to show.
- * @param[in] force Set to @c true to force show even if unchanged.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI void efl_ui_widget_show_region_set(Eo *obj, Eina_Rect region, Eina_Bool force);
-#endif
-
-#ifdef EFL_UI_WIDGET_PROTECTED
-/**
- * @brief Region inside the widget to show.
- *
- * See also @ref efl_ui_widget_on_show_region_hook_set.
- *
- * Returns the current region to show.
- *
- * @param[in] obj The object.
- *
- * @return The region to show.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI Eina_Rect efl_ui_widget_show_region_get(const Eo *obj);
+EOAPI Eina_Error efl_ui_widget_theme_apply(Eo *obj);
 #endif
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Push scroll hold
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI void efl_ui_widget_scroll_hold_push(Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Pop scroller hold
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI void efl_ui_widget_scroll_hold_pop(Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Push scroller freeze
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI void efl_ui_widget_scroll_freeze_push(Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Pop scroller freeze
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI void efl_ui_widget_scroll_freeze_pop(Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_UI_WIDGET_PROTECTED
 /**
@@ -581,45 +635,18 @@ EOAPI void efl_ui_widget_scroll_freeze_pop(Eo *obj);
  * greater or equal to 1 for this region to be taken into account, otherwise it
  * is ignored.
  *
- * See also @ref efl_ui_widget_interest_region_mode_get
- *
  * @param[in] obj The object.
  *
  * @return The relative region to show. If width or height is <= 0 it will be
  * ignored, and no action will be taken.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI Eina_Rect efl_ui_widget_interest_region_get(const Eo *obj);
 #endif
 
-/**
- * @brief Defines how @ref efl_ui_widget_show_region_get should be calculated.
- *
- * It is up to the implementation of @ref efl_ui_widget_show_region_get to take
- * this value into account (or ignore it).
- *
- * @param[in] obj The object.
- * @param[in] mode Whether to show a specific item or the widget as a whole.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI void efl_ui_widget_interest_region_mode_set(Eo *obj, Efl_Ui_Interest_Region_Mode mode);
-
-/**
- * @brief Defines how @ref efl_ui_widget_show_region_get should be calculated.
- *
- * It is up to the implementation of @ref efl_ui_widget_show_region_get to take
- * this value into account (or ignore it).
- *
- * @param[in] obj The object.
- *
- * @return Whether to show a specific item or the widget as a whole.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI Efl_Ui_Interest_Region_Mode efl_ui_widget_interest_region_mode_get(const Eo *obj);
-
 #ifdef EFL_UI_WIDGET_PROTECTED
 /**
  * @brief The rectangle region to be highlighted on focus.
@@ -632,160 +659,28 @@ EOAPI Efl_Ui_Interest_Region_Mode efl_ui_widget_interest_region_mode_get(const E
  *
  * @return The rectangle area.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI Eina_Rect efl_ui_widget_focus_highlight_geometry_get(const Eo *obj);
 #endif
 
-/**
- * @brief Whether focus highlight is enabled or not.
- *
- * As of EFL 1.21 focus highlight properties apply to a single window, not a
- * single widget. As a consequence, calls to this function may be forwarded to
- * the parent window. Future versions of EFL may implement widget-specific
- * focus highlight properties.
- *
- * See also @ref efl_ui_widget_top_get. See also
- * @ref efl_ui_widget_focus_highlight_style_get. See also
- * @ref efl_ui_widget_focus_highlight_animate_get.
- *
- * Set the enabled status for the focus highlight in a window.
- *
- * This function will enable or disable the focus highlight, regardless of the
- * global setting for it.
- *
- * @param[in] obj The object.
- * @param[in] enabled The enabled value for the highlight.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI void efl_ui_widget_focus_highlight_enabled_set(Eo *obj, Eina_Bool enabled);
-
-/**
- * @brief Whether focus highlight is enabled or not.
- *
- * As of EFL 1.21 focus highlight properties apply to a single window, not a
- * single widget. As a consequence, calls to this function may be forwarded to
- * the parent window. Future versions of EFL may implement widget-specific
- * focus highlight properties.
- *
- * See also @ref efl_ui_widget_top_get. See also
- * @ref efl_ui_widget_focus_highlight_style_get. See also
- * @ref efl_ui_widget_focus_highlight_animate_get.
- *
- * Get the enabled value of the focus highlight for this window.
- *
- * @param[in] obj The object.
- *
- * @return The enabled value for the highlight.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI Eina_Bool efl_ui_widget_focus_highlight_enabled_get(const Eo *obj);
-
-/**
- * @brief Control the widget focus highlight style.
- *
- * If @c style is @c null, the default will be used.
- *
- * As of EFL 1.21 focus highlight properties apply to a single window, not a
- * single widget. As a consequence, calls to this function may be forwarded to
- * the parent window. Future versions of EFL may implement widget-specific
- * focus highlight properties.
- *
- * See also @ref efl_ui_widget_top_get. See also
- * @ref efl_ui_widget_focus_highlight_enabled_get. See also
- * @ref efl_ui_widget_focus_highlight_animate_get.
- *
- * @param[in] obj The object.
- * @param[in] style The name of the focus highlight style.
- *
- * @return @c true on success, @c false otherwise.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI Eina_Bool efl_ui_widget_focus_highlight_style_set(Eo *obj, const char *style);
-
-/**
- * @brief Control the widget focus highlight style.
- *
- * If @c style is @c null, the default will be used.
- *
- * As of EFL 1.21 focus highlight properties apply to a single window, not a
- * single widget. As a consequence, calls to this function may be forwarded to
- * the parent window. Future versions of EFL may implement widget-specific
- * focus highlight properties.
- *
- * See also @ref efl_ui_widget_top_get. See also
- * @ref efl_ui_widget_focus_highlight_enabled_get. See also
- * @ref efl_ui_widget_focus_highlight_animate_get.
- *
- * @param[in] obj The object.
- *
- * @return The name of the focus highlight style.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI const char *efl_ui_widget_focus_highlight_style_get(const Eo *obj);
-
-/**
- * @brief Whether focus highlight should animate or not.
- *
- * As of EFL 1.21 focus highlight properties apply to a single window, not a
- * single widget. As a consequence, calls to this function may be forwarded to
- * the parent window. Future versions of EFL may implement widget-specific
- * focus highlight properties.
- *
- * See also @ref efl_ui_widget_top_get. See also
- * @ref efl_ui_widget_focus_highlight_style_get. See also
- * @ref efl_ui_widget_focus_highlight_enabled_get.
- *
- * Set the animate status for the focus highlight for this window.
- *
- * This function will enable or disable the animation of focus highlight.
- *
- * @param[in] obj The object.
- * @param[in] animate The enabled value for the highlight animation.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI void efl_ui_widget_focus_highlight_animate_set(Eo *obj, Eina_Bool animate);
-
-/**
- * @brief Whether focus highlight should animate or not.
- *
- * As of EFL 1.21 focus highlight properties apply to a single window, not a
- * single widget. As a consequence, calls to this function may be forwarded to
- * the parent window. Future versions of EFL may implement widget-specific
- * focus highlight properties.
- *
- * See also @ref efl_ui_widget_top_get. See also
- * @ref efl_ui_widget_focus_highlight_style_get. See also
- * @ref efl_ui_widget_focus_highlight_enabled_get.
- *
- * Get the animate value of the focus highlight for this window.
- *
- * @param[in] obj The object.
- *
- * @return The enabled value for the highlight animation.
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI Eina_Bool efl_ui_widget_focus_highlight_animate_get(const Eo *obj);
-
-#ifdef EFL_UI_WIDGET_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief The widget's focus move policy.
  *
  * @param[in] obj The object.
  * @param[in] policy Focus move policy
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI void efl_ui_widget_focus_move_policy_set(Eo *obj, Efl_Ui_Focus_Move_Policy policy);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_UI_WIDGET_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief The widget's focus move policy.
  *
@@ -793,12 +688,14 @@ EOAPI void efl_ui_widget_focus_move_policy_set(Eo *obj, Efl_Ui_Focus_Move_Policy
  *
  * @return Focus move policy
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI Efl_Ui_Focus_Move_Policy efl_ui_widget_focus_move_policy_get(const Eo *obj);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_UI_WIDGET_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Control the widget's focus_move_policy mode setting.
  *
@@ -806,14 +703,14 @@ EOAPI Efl_Ui_Focus_Move_Policy efl_ui_widget_focus_move_policy_get(const Eo *obj
  * @param[in] automatic @c true to follow system focus move policy change,
  * @c false otherwise
  *
- * @since 1.18
+ * @since 1.22
  *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI void efl_ui_widget_focus_move_policy_automatic_set(Eo *obj, Eina_Bool automatic);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
-#ifdef EFL_UI_WIDGET_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Control the widget's focus_move_policy mode setting.
  *
@@ -822,77 +719,61 @@ EOAPI void efl_ui_widget_focus_move_policy_automatic_set(Eo *obj, Eina_Bool auto
  * @return @c true to follow system focus move policy change, @c false
  * otherwise
  *
- * @since 1.18
+ * @since 1.22
  *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI Eina_Bool efl_ui_widget_focus_move_policy_automatic_get(const Eo *obj);
-#endif
-
-#ifdef EFL_UI_WIDGET_BETA
-/**
- * @brief Get the focused widget item.
- *
- * @param[in] obj The object.
- *
- * @return Focused item
- *
- * @ingroup Efl_Ui_Widget
- */
-EOAPI Elm_Widget_Item *efl_ui_widget_focused_item_get(const Eo *obj);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_UI_WIDGET_PROTECTED
 /**
- * @brief Register focus with the given configuration.
+ * @brief Apply a new focus state on the widget.
  *
- * The implementation can feel free to change the logical flag as it wants, but
- * other than that it should strictly keep the configuration.
+ * This method is called internally by @ref Efl_Ui_Widget. Override it to
+ * change how a widget interacts with its focus manager. If a widget desires to
+ * change the applied configuration, it has to modify @c configured_state in
+ * addition to any internal changes.
  *
- * The implementation in elm.widget updates the current state into what is
- * passed as configured state, respecting manager changes, registeration and
- * unregistration based on if it should be registered or unregistered.
- *
- * A manager field that is @c null means that the widget should not or was not
- * registered.
+ * The default implementation (when this method is not overridden) applies
+ * @c configured_state using the @c manager contained inside.
  *
  * @param[in] obj The object.
- * @param[in] current_state The focus manager to register with.
- * @param[in,out] configured_state The evalulated Focus state that should be
- * used.
- * @param[in] redirect A redirect that will be set by the elm.widget
- * implementation.
+ * @param[in] current_state The current focus configuration of the widget.
+ * @param[in,out] configured_state The new configuration being set on the
+ * widget.
+ * @param[in] redirect A redirect object if there is any
  *
- * @return Returns whether the widget is registered or not.
+ * @return Returns @c true if the widget is registered in the focus manager,
+ * @c false if not.
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Ui_Widget
  */
 EOAPI Eina_Bool efl_ui_widget_focus_state_apply(Eo *obj, Efl_Ui_Widget_Focus_State current_state, Efl_Ui_Widget_Focus_State *configured_state, Efl_Ui_Widget *redirect);
 #endif
-
-EWAPI extern const Efl_Event_Description _EFL_UI_WIDGET_EVENT_MOVED;
-
-/** Called when widget moved
- * @return Efl_Object *
- *
- * @ingroup Efl_Ui_Widget
- */
-#define EFL_UI_WIDGET_EVENT_MOVED (&(_EFL_UI_WIDGET_EVENT_MOVED))
-
+#ifdef EFL_BETA_API_SUPPORT
 EWAPI extern const Efl_Event_Description _EFL_UI_WIDGET_EVENT_LANGUAGE_CHANGED;
 
 /** Called when widget language changed
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Ui_Widget
  */
 #define EFL_UI_WIDGET_EVENT_LANGUAGE_CHANGED (&(_EFL_UI_WIDGET_EVENT_LANGUAGE_CHANGED))
-
+#endif /* EFL_BETA_API_SUPPORT */
+#ifdef EFL_BETA_API_SUPPORT
 EWAPI extern const Efl_Event_Description _EFL_UI_WIDGET_EVENT_ACCESS_CHANGED;
 
 /** Called when accessibility changed
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Ui_Widget
  */
 #define EFL_UI_WIDGET_EVENT_ACCESS_CHANGED (&(_EFL_UI_WIDGET_EVENT_ACCESS_CHANGED))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
