@@ -13,6 +13,7 @@ typedef Eo Efl_Ui_Win_Inlined;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief An inlined window.
  *
@@ -38,5 +39,6 @@ EWAPI const Efl_Class *efl_ui_win_inlined_class_get(void);
  * @ingroup Efl_Ui_Win_Inlined
  */
 EOAPI Efl_Canvas_Object *efl_ui_win_inlined_parent_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
